require_dependency Hyrax::Engine.root.join('app', 'controllers', 'hyrax', 'dashboard', 'collections_controller').to_s

module Hyrax
  module Dashboard
    ## Shows a list of all collections to the admins
    class CollectionsController < Hyrax::My::CollectionsController

      ##
      # Responds to an ajax call and updates the work order
      def update_work_order
        per_page = params[:per_page] == 'null' ? blacklight_config.default_per_page : params[:per_page].to_i
        page = params[:page] == 'null' ? 1 : params[:page].to_i

        number_of_works = ActiveFedora::Base.where("member_of_collection_ids_ssim:#{@collection.id} AND has_model_ssim:Image").count
        # we're only updating a page at time in theory so get the subset of the array we're updating
        items_to_update = JSON.parse(params[:order])

        full_collection_order = @collection.work_order

        # number of items in this update
        number_to_update = items_to_update.length

        # the starting offset of the page to merge this is into the overall array
        initial_offset = page == 1 ? 0 : (page - 1) * per_page

        # the ending offset of the page to merge this into the array corrected for the end of the collection
        ending_offset = page * per_page > number_of_works ? number_of_works : page * per_page

        #update the overall collection
        full_collection_order[initial_offset,ending_offset] = items_to_update

        @collection.update_order(full_collection_order, :work)
      end

      ##
      # Responds to an ajax call and updates the subcollection order
      def update_subcollection_order
        new_order = JSON.parse(params[:order])
        @collection.update_order(new_order, :subcollection) unless new_order.blank?
      end

      private

        ##
        # Overwritten to remove ids from CollectionOrder as well.
        def remove_members_from_collection
          batch.each do |pid|
            work = ActiveFedora::Base.find(pid)
            work.member_of_collections.delete @collection
            work.save!

            remove_id_from_work_order(pid)
          end
        end

        ##
        # Removes an id from the collection's work order
        # @param {str} id
        #   The id to remove from the order
        def remove_id_from_work_order(id)
          order = @collection.work_order
          return if order.blank?
          new_order = order - [id]
          @collection.update_order(new_order, :work) unless new_order == order
        end
    end
  end
end
